@@ -10,6 +10,9 @@ from devsecops_engine_tools.engine_core.src.infrastructure.driven_adapters.aws.s
 from devsecops_engine_tools.engine_core.src.infrastructure.driven_adapters.azure.azure_devops import (
     AzureDevops,
 )
+from devsecops_engine_tools.engine_core.src.infrastructure.driven_adapters.github.github_actions import (
+    GithubActions,
+)
 from devsecops_engine_tools.engine_core.src.infrastructure.driven_adapters.runtime_local.runtime_local import (
     RuntimeLocal,
 )
@@ -45,7 +48,7 @@ def parse_choices(choices):
 def get_inputs_from_cli(args):
     parser = argparse.ArgumentParser()
     parser.add_argument("-v", "--version", action='version', version='{version}'.format(version=version))
-    parser.add_argument("-pd", "--platform_devops", choices=["azure", "local"], type=str, required=True, help="Platform where is executed")
+    parser.add_argument("-pd", "--platform_devops", choices=["azure", "github", "local"], type=str, required=True, help="Platform where is executed")
     parser.add_argument("-rcf" ,"--remote_config_repo", type=str, required=True, help="Name or Folder Path of Config Repo")
     parser.add_argument("-t",
         "--tool",
@@ -114,7 +117,11 @@ def application_core():
         # Define driven adapters for gateways
         vulnerability_management_gateway = DefectDojoPlatform()
         secrets_manager_gateway = SecretsManager()
-        devops_platform_gateway = AzureDevops() if args["platform_devops"] == "azure" else RuntimeLocal()
+        devops_platform_gateway = {
+            "azure": AzureDevops(),
+            "github": GithubActions(),
+            "local": RuntimeLocal()
+        }.get(args["platform_devops"])
         printer_table_gateway = PrinterPrettyTable()
         metrics_manager_gateway = S3Manager()
         
